/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.location;

import com.vladmihalcea.hibernate.type.json.JsonBinaryType;
import com.yiring.common.domain.BasicEntity;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.TypeDef;

/**
 * 定位进出记录
 *
 * @author Jim
 * @version 0.1
 * 2022/5/12 17:54
 */

@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@TypeDef(name = "jsonb", typeClass = JsonBinaryType.class)
@Table(name = "BS_LOCATION_TURNOVER", indexes = { @Index(columnList = "type"), @Index(columnList = "sourceId") })
@Comment("定位进出记录")
public class LocationTurnover extends BasicEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 887764448464587364L;

    @Comment("进出区域/围栏表主键")
    Long sourceId;

    @Comment("类型")
    @Enumerated(EnumType.STRING)
    Type type;

    @Comment("定位标签")
    @ManyToOne(fetch = FetchType.LAZY)
    LocationTag tag;

    @Comment("定位时间")
    LocalDateTime time;

    @Comment("进入")
    Boolean enter;

    @Comment("是否为最新状态")
    Boolean isLatest;

    @SuppressWarnings({ "unused" })
    public enum Type {
        FENCE("围栏"),
        DISTRICT("区域");

        final String text;

        Type(String text) {
            this.text = text;
        }

        public String text() {
            return this.text;
        }
    }
}
