/* (C) 2022 YiRing, Inc. */
package com.yiring.app.rabbit.receiver;

import com.rabbitmq.client.Channel;
import com.yiring.app.service.message.PositionMessageService;
import com.yiring.common.annotation.Times;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import javax.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.listener.api.ChannelAwareMessageListener;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

/**
 * 真源消息监听处理器
 *
 * @author Jim
 * @version 0.1
 * 2022/5/11 16:35
 */

@Slf4j
@Component
@Transactional(rollbackFor = Exception.class)
public class PositionMessageHandler implements ChannelAwareMessageListener {

    // TODO
    // 1. 新增消息订阅定时任务，检查是否正常订阅了真源定位系统的消息
    // 2. 如果没有所需的订阅记录，则发起消息订阅（见接口文档: 6.2）
    // 3. 订阅 position（定位数据）、lowPower（低电量报警）、deviceStatus（设备状态）、keyWarning（按键报警）

    @Resource
    PositionMessageService positionMessageService;

    @Times("Position System Message Handler")
    @Override
    public void onMessage(Message message, Channel channel) throws IOException {
        // 消费消息
        positionMessageService.consume(new String(message.getBody(), StandardCharsets.UTF_8));
        // 手动确认消息已收到
        assert channel != null;
        channel.basicAck(message.getMessageProperties().getDeliveryTag(), false);
    }
}
